import {ScrollView, View} from "@tarojs/components";
import {FC, useState} from "react";
import {Category, HomeApi} from "@/api";
import Taro from "@tarojs/taro";
import styles from './sort.module.scss'

const prefix = 'SORT'
const Sort: FC = () => {
  const [data, setData] = useState<Category[]>([])
  const [select, setSelect] = useState<string | null>(null)

  async function getData() {
    const res = await HomeApi.category(3)
    setData(res)
    if (res.length) {
      setSelect(`${prefix}-${res[0].id}`)
    }
  }

  function jump(id: number) {
    Taro.navigateTo({url: '/pages/preview/illness/list/list?id=' + id})
  }

  Taro.useLoad(getData)

  return (
    <View className='flex'>
      <ScrollView
        scrollY
        scrollWithAnimation
        scrollIntoView={select!}
        className={styles.firstOrder}>
        {
          data.map(d => <View
            id={`${prefix}-${d.id}`}
            key={d.id}
            onClick={() => setSelect(`${prefix}-${d.id}`)}
            className={`${select === `${prefix}-${d.id}` && styles.select}`}>
            {d.name}
          </View>)
        }
      </ScrollView>

      <ScrollView
        scrollY
        className={styles.tree}
        scrollWithAnimation
        scrollIntoView={select!}>
        {
          data.map(d => <View key={d.id} id={`${prefix}-${d.id}`}>
              <View className={styles.name}
                    style={{color: (select === `${prefix}-${d.id}` ? '#45D4A8' : undefined)}}>{d.name}</View>
              <View className={styles.secondaryBox}>
                {
                  d.resource_category?.map(c => <View
                    onClick={() => jump(d.id)}
                    key={d.id}
                    className={styles.secondary}>
                    <View className='p-1'>{c.name}</View>
                  </View>)
                }
              </View>
            </View>
          )
        }
      </ScrollView>
    </View>
  )
}

export default Sort
